==> Paws-0.14.tar.gz: Paws-0.14/lib/Paws/CodeDeploy/DeregisterOnPremisesInstance.pm <==

package Paws::CodeDeploy::DeregisterOnPremisesInstance {
  use Moose;
  has instanceName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeregisterOnPremisesInstance');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::DeregisterOnPremisesInstance - Arguments for method DeregisterOnPremisesInstance on Paws::CodeDeploy

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeregisterOnPremisesInstance on the 
AWS CodeDeploy service. Use the attributes of this class
as arguments to method DeregisterOnPremisesInstance.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DeregisterOnPremisesInstance.

As an example:

  $service_obj->DeregisterOnPremisesInstance(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> instanceName => Str

  

The name of the on-premises instance to deregister.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeregisterOnPremisesInstance in L<Paws::CodeDeploy>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.15.tar.gz: Paws-0.15/lib/Paws/CodeDeploy/DeregisterOnPremisesInstance.pm <==

package Paws::CodeDeploy::DeregisterOnPremisesInstance;
  use Moose;
  has instanceName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeregisterOnPremisesInstance');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodeDeploy::DeregisterOnPremisesInstance - Arguments for method DeregisterOnPremisesInstance on Paws::CodeDeploy

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeregisterOnPremisesInstance on the 
AWS CodeDeploy service. Use the attributes of this class
as arguments to method DeregisterOnPremisesInstance.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DeregisterOnPremisesInstance.

As an example:

  $service_obj->DeregisterOnPremisesInstance(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> instanceName => Str

  

The name of the on-premises instance to deregister.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeregisterOnPremisesInstance in L<Paws::CodeDeploy>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
